@@ -9,11 +9,12 @@
 #' @seealso
 #'   Use \code{\link{save_beast_trees}} to save the phylogenies
 #'   to a \code{.trees} file.
+#'   Use \link{is_trees_file} with \code{verbose = TRUE} to find out
+#'   why a file is invalid
 #' @author Richèl J.C. Bilderbeek
 parse_beast_trees <- function(
   filename
 ) {
-
   if (!file.exists(filename)) {
     stop(
       "'filename' is the name of an absent file. ",
@@ -21,15 +22,32 @@ parse_beast_trees <- function(
     )
   }
 
+  # Do not warn about 'incomplete final line found on ...'
+  lines <- readLines(filename, warn = FALSE)
+  last_line <- lines[length(lines)]
+  # BEAST2 saves as 'End;', where ape saves as 'END;'
+  if (last_line != "End;" && last_line != "END;") {
+    stop(
+      "Expect 'End;' (BEAST2) or 'END;' (ape::write.nexus) at the ",
+      "end of .trees file \n",
+      "Actual value: ", last_line
+    )
+  }
+
   trees <- tryCatch({
       # Cannot use ape::read.tree, as that's incompatible with BEAST2's output
+      # Do not use force.multi, as STATE_ will be lost
       ape::read.nexus(filename)
     },
-    error = function(cond) {
-      stop("invalid file")
+    error = function(e) {
+      stop(
+        "invalid file '", filename, "' \n",
+        "error message: ", e$message
+      )
     }
   )
 
+  testit::assert(is_trees_file(filename)) # nolint tracerer function
   testit::assert(length(trees) != 1 || !is.na(trees))
 
 
